DataLad extension crawling web resources and automated data distributions
*************************************************************************

.. toctree::
   :maxdepth: 1

   changelog
   acknowledgements
   basics

Demo
====

.. toctree::
   :maxdepth: 1

   demos/track_data_from_webpage


Command line reference
======================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-crawl
   generated/man/datalad-crawl-init


Python API
==========

.. toctree::
   :maxdepth: 1

   modref


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
